#ifdef AVEVAD
#define _GLIBCXX_DEBUG
#else
#pragma GCC optimize("Ofast,unroll-loops")
//#pragma GCC target("tune=native")
#endif

#include <bits/stdc++.h>

using namespace std;
using ll = long long;

const ll INF = 1e18;

struct E {
    ll q, x, i, f;
};

bool operator<(const E &a, const E &b) {
    if (a.x != b.x) return a.x < b.x;
    if (a.f != b.f) return a.f;
    return 0;
}

bool is_tied(const set<ll> &as0, const set<ll> &as1, const set<ll> &bs0, const set<ll> &bs1) {
    return !as1.empty() && !bs0.empty() && (*as1.rbegin() == *bs0.begin());
}

template<typename T>
void upd(T &a, const T &b) {
    if (b > a) a = b;
}

ll solve(const vector<ll> &v0, const vector<ll> &v1) {
    ll n = v0.size();
    vector<ll> d0(n, -INF), d1(n, -INF);
    d0[0] = v0[0];
    d1[0] = v1[0];
    for (ll i = 1; i < n; i++) {
        upd(d0[i], d0[i - 1] + v0[i] - 1);
        upd(d0[i], d1[i - 1] + v0[i] - 1);
        upd(d1[i], d0[i - 1] + v1[i]);
        upd(d1[i], d1[i - 1] + v1[i] - 1);
    }
    return max(d0.back(), d1.back());
}

ll solve_fast(const vector<pair<ll, ll>> &a0, const vector<pair<ll, ll>> &a1, const vector<pair<ll, ll>> &b) {
    ll n = a0.size();
    ll m = b.size();
    vector<E> v;
    for (ll i = 0; i < n; i++) {
        v.push_back({0, a0[i].first, i, 0});
        v.push_back({0, a0[i].second, i, 1});
        v.push_back({1, a1[i].first, i, 0});
        v.push_back({1, a1[i].second, i, 1});
    }
    for (ll j = 0; j < m; j++) {
        v.push_back({2, b[j].first, j, 0});
        v.push_back({2, b[j].second, j, 1});
    }
    sort(v.begin(), v.end());
    vector<set<ll>> s0(n), s1(n);
    {
        ll i0 = -1, i1 = -1, j = -1;
        for (auto e : v) {
            if (e.q == 2) {
                if (e.f == 0) {
                    j = e.i;
                    if (i0 != -1) s0[i0].insert(j);
                    if (i1 != -1) s1[i1].insert(j);
                } else j = -1;
            } else {
                if (e.f == 0) {
                    (e.q ? i1 : i0) = e.i;
                    if (j != -1) (e.q ? s1 : s0)[e.i].insert(j);
                } else (e.q ? i1 : i0) = -1;
            }
        }
    }
    ll cnt_free = 0;
    {
        vector<ll> w(m);
        for (ll i = 0; i < n; i++) {
            for (ll j : s0[i]) w[j] = 1;
            for (ll j : s1[i]) w[j] = 1;
        }
        for (ll j = 0; j < m; j++) if (!w[j]) cnt_free++;
    }
    vector<ll> bad(m);
    for (ll i = 0; i < n; i++) for (ll j : s0[i]) if (s1[i].find(j) != s1[i].end()) bad[j] = 1;
    for (ll i = 0; i < n; i++) {
        for (auto it = s0[i].begin(); it != s0[i].end();) {
            if (bad[*it]) it = s0[i].erase(it);
            else it++;
        }
        for (auto it = s1[i].begin(); it != s1[i].end();) {
            if (bad[*it]) it = s1[i].erase(it);
            else it++;
        }
    }
    ll ans = 0;
    vector<ll> v0, v1;
    for (ll i = 0; i < n; i++) {
        v0.push_back(s0[i].size());
        v1.push_back(s1[i].size());
        if (i == n - 1 || !is_tied(s0[i], s1[i], s0[i + 1], s1[i + 1])) {
            ans += solve(v0, v1);
            v0.clear();
            v1.clear();
        }
    }
    ans += cnt_free;
    return ans;
}

bool intersects(const pair<ll, ll> &a, const pair<ll, ll> &b) {
    if (a.second <= b.first) return 0;
    if (b.second <= a.first) return 0;
    return 1;
}

ll solve_stupid(const vector<pair<ll, ll>> &a0, const vector<pair<ll, ll>> &a1, const vector<pair<ll, ll>> &b) {
    ll n = a0.size();
    ll m = b.size();
    ll ans = 0;
    for (ll t = 0; t < (1ll << n); t++) {
        vector<ll> bad(m);
        for (ll i = 0; i < n; i++) {
            ll f = (t >> i) % 2ll;
            ll l = f ? a1[i].first : a0[i].first;
            ll r = f ? a1[i].second : a0[i].second;
            for (ll j = 0; j < m; j++) if (intersects({l, r}, b[j])) bad[j] = 1;
        }
        ll cur = 0;
        for (ll j = 0; j < m; j++) if (!bad[j]) cur++;
        ans = max(ans, cur);
    }
    return ans;
}

void stress() {
    const ll N = 5, M = 7, X = 30;
    mt19937_64 rng(123);
    for (ll t = 0; t < 100; t++) {
        vector<ll> a;
        while (ll(a.size()) != 4 * N) {
            for (ll i = 0; i < 4 * N - ll(a.size()); i++) a.push_back(rng() % X);
            sort(a.begin(), a.end());
            a.resize(unique(a.begin(), a.end()) - a.begin());
        }
        vector<ll> bb;
        while (ll(bb.size()) != 2 * M) {
            for (ll i = 0; i < 2 * M - ll(bb.size()); i++) bb.push_back(rng() % X);
            sort(bb.begin(), bb.end());
            bb.resize(unique(bb.begin(), bb.end()) - bb.begin());
        }
        vector<pair<ll, ll>> a0(N), a1(N);
        vector<pair<ll, ll>> b(M);
        for (ll i = 0; i < N; i++) {
            a0[i] = {a[4 * i + 0], a[4 * i + 1]};
            a1[i] = {a[4 * i + 2], a[4 * i + 3]};
        }
        for (ll j = 0; j < M; j++) {
            b[j] = {bb[2 * j + 0], bb[2 * j + 1]};
        }
        ll ans_f = solve_fast(a0, a1, b);
        ll ans_s = solve_stupid(a0, a1, b);
        if (ans_f != ans_s) {
            cout << t << " fail" << endl;
            exit(1);
        } else cout << t << " OK" << endl;
    }
}

int main() {
#ifndef AVEVAD
    //cin.tie(0);
    //ios_base::sync_with_stdio(0);
#endif
#ifdef AVEVAD
    stress();
    return 0;
#endif
    ll n, m;
    cin >> n >> m;
    vector<pair<ll, ll>> a0(n), a1(n);
    vector<pair<ll, ll>> b(m);
    for (ll i = 0; i < n; i++) {
        ll fl, fr, sl, sr;
        cin >> fl >> fr >> sl >> sr;
        fl--, sl--;
        a0[i] = {fl, fr};
        a1[i] = {sl, sr};
    }
    for (ll j = 0; j < m; j++) {
        ll l, r;
        cin >> l >> r;
        l--;
        b[j] = {l, r};
    }
    ll ans = solve_fast(a0, a1, b);
    cout << ans << '\n';
    return 0;
}
/*
4 12
1 2 4 7
8 10 12 12
14 18 21 22
27 30 32 33
1 1
2 2
4 5
7 9
10 10
12 14
16 17
18 18
22 23
27 28
30 30
33 33
 */