#include <iostream>
#include <iomanip>
#include <cassert>
#include <vector>
#include <numeric>
#include <string>
#include <bitset>
#include <cmath>
#include <algorithm>
#include <stack>
#include <queue>
#include <deque>
#include <set>
#include <unordered_set>
#include <map>
#include <unordered_map>
#include <random>
#include <ctime>
#include <chrono>

using namespace std;

#define all(x) (x).begin(), (x).end()
#define rall(x) (x).rbegin(), (x).rend()
#define sz(x) (int)((x).size())

typedef long long ll;
typedef long double ld;
typedef pair<int, int> pii;
typedef pair<ll, ll> pll;

const char en = '\n';
const int INF = 1e9 + 7;
const ll INFLL = 1e18;

mt19937 rnd(chrono::high_resolution_clock::now().time_since_epoch().count());

const long double PI = acos(-1);

struct Point {
    ld x = 0, y = 0;

    Point() : x(0), y(0) {}
    Point(ld _x, ld _y) : x(_x), y(_y) {}

};

struct Vector {
    ld x, y;

    Vector() : x(0), y(0) {}
    Vector(ld _x, ld _y) : x(_x), y(_y) {}
    Vector(Point a, Point b) : x(b.x - a.x), y(b.y - a.y) {}

    ld len() const {
        return sqrtl(x * x + y * y);
    }

    ld sqlen() const {
        return (x * x + y * y);
    }

    ld operator *(const Vector other) const {
        return x * other.x + y * other.y;
    }

    ld operator %(const Vector other) const {
        return x * other.y - y * other.x;
    }
};

typedef vector<Point> Polygon;

bool angle_check(const Point &p, const Point &a, const Point &o, const Point &b) {
    Vector oa(o, a), ob(o, b), op(o, p);
    if ((oa % ob) < 0) swap(oa, ob);
    return ((oa % op) >= 0 && (ob % op) <= 0);
}

int check(const Point &p, const Polygon &poly) {
    int n = sz(poly);
    if (angle_check(p, poly[n - 1], poly[0], poly[1])) {
        int l = 1, r = n - 1;
        while (r - l > 1) {
            int md = (l + r) / 2;
            if (angle_check(p, poly[md], poly[0], poly[l])) {
                r = md;
            }
            else {
                l = md;
            }
        }
        if (angle_check(p, poly[r], poly[0], poly[l]) &&
            angle_check(p, poly[0], poly[l], poly[r]) &&
            angle_check(p, poly[l], poly[r], poly[0])) {
            return 1;
        }
        else {
            return 0;
        }
    }
    else {
        return 0;
    }
}

int gcd(int a, int b) {
    if (b == 0) {
        return a;
    }
    return gcd(b, a % b);
}

void solve() {
    int n;
    cin >> n;
    Polygon a(n);
    for (int i = 0; i < n; ++i) {
        cin >> a[i].x >> a[i].y;
    }
    int ans = 0;
    int N = 1e3;
    for (int i = 1; i <= N; ++i) {
        for (int j = i; j <= N; ++j) {
            if (gcd(i, j) == 1) {
                ans += check(Point(i, j), a);
                if (i != j) {
                    ans += check(Point(j, i), a);
                }
            }
        }
    }
    cout << ans << en;
}

int main() {
#ifdef __APPLE__
    freopen("input.txt", "r", stdin);
#else
    ios_base::sync_with_stdio(0); cin.tie(0);
#endif
    solve();
    return 0;
}