#include <iostream>
#include <iomanip>
#include <cassert>
#include <vector>
#include <numeric>
#include <string>
#include <bitset>
#include <cmath>
#include <algorithm>
#include <stack>
#include <queue>
#include <deque>
#include <set>
#include <unordered_set>
#include <map>
#include <unordered_map>
#include <random>
#include <ctime>
#include <chrono>

using namespace std;

#define all(x) (x).begin(), (x).end()
#define rall(x) (x).rbegin(), (x).rend()
#define sz(x) (int)((x).size())

typedef long long ll;
typedef long double ld;
typedef pair<int, int> pii;
typedef pair<ll, ll> pll;

const char en = '\n';
const int INF = 1e9 + 7;
const ll INFLL = 1e18;

mt19937 rnd(chrono::high_resolution_clock::now().time_since_epoch().count());

struct Node {
    ll ans = 0;
    ll pushed = 0;
    int l, r;
    int L = -1, R = -1;

    Node() {}
};

vector<Node> tree;

void make_son(int v) {
    if (tree[v].L == -1) {
        tree[v].L = sz(tree);
        tree.emplace_back();
        tree.back().l = tree[v].l;
        tree.back().r = (tree[v].l + (tree[v].r - tree[v].l)) / 2;
    }
    if (tree[v].R == -1) {
        tree[v].R = sz(tree);
        tree.emplace_back();
        tree.back().l = (tree[v].l + (tree[v].r - tree[v].l)) / 2;
        tree.back().r = tree[v].r;
    }
}

void push(int v, int l, int r) {
    if (tree[v].pushed == 0) {
        return;
    }
    tree[v].ans += tree[v].pushed;
    if (l + 1 != r) {
        make_son(v);
        tree[tree[v].L].pushed += tree[v].pushed;
        tree[tree[v].R].pushed += tree[v].pushed;
    }
    tree[v].pushed = 0;
}

void update_vertex(int v, int l, int r) {
    make_son(v);
    int m = l + (r - l) / 2, vL = tree[v].L, vR = tree[v].R;
    push(vL, l, m);
    push(vR, m, r);
    tree[v].ans = min(tree[vL].ans, tree[vR].ans);
}

void update_tree(int v, int l, int r, int ql, int qr, ll val) {
    push(v, l, r);
    if (ql <= l && r <= qr) {
        tree[v].pushed += val;
        push(v, l, r);
        return;
    }
    make_son(v);
    int m = l + (r - l) / 2, vL = tree[v].L, vR = tree[v].R;
    if (ql < m) update_tree(vL, l, m, ql, qr, val);
    if (m < qr) update_tree(vR, m, r, ql, qr, val);
    update_vertex(v, l, r);
}

void solve() {
    ll n, m, q;
    cin >> n >> m >> q;
    tree.emplace_back();
    tree[0].l = 0;
    tree[0].r = m;
    while (q--) {
        ll l, r;
        cin >> l >> r;
        --l; --r;
        ll bl_l = l / m, bl_r = r / m;
        if (bl_l == bl_r) {
            update_tree(0, 0, m, l % m, r % m, 1);
        }
        else {
            ll d = bl_r - bl_l - 1;
            update_tree(0, 0, m, 0, m, d);
            update_tree(0, 0, m, l % m, m, 1);
            update_tree(0, 0, m, 0, r % m + 1, 1);
        }
    }
    cout << tree[0].ans << en;
}

int main() {
#ifdef __APPLE__
    freopen("input.txt", "r", stdin);
#else
    ios_base::sync_with_stdio(0); cin.tie(0);
#endif
    solve();
    return 0;
}